@@ -1,13 +1,8 @@
 import os
 import warnings
-
 from contextlib import contextmanager
-from pathlib import Path
 from functools import wraps
-
-
-CALITP_BQ_MAX_BYTES = os.environ.get("CALITP_BQ_MAX_BYTES", 5_000_000_000)
-CALITP_BQ_LOCATION = os.environ.get("CALITP_BQ_LOCATION", "us-west2")
+from pathlib import Path
 
 
 class RequiresAdminWarning(UserWarning):
